aboutsummaryrefslogtreecommitdiff
path: root/src/superio/fintek/f71859/superio.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/superio/fintek/f71859/superio.c')
-rwxr-xr-xsrc/superio/fintek/f71859/superio.c5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/superio/fintek/f71859/superio.c b/src/superio/fintek/f71859/superio.c
index 445f66a6b5..d7d71c6ec8 100755
--- a/src/superio/fintek/f71859/superio.c
+++ b/src/superio/fintek/f71859/superio.c
@@ -87,9 +87,8 @@ static struct device_operations ops = {
};
static struct pnp_info pnp_dev_info[] = {
- /* TODO: Some of the 0x7f8 etc. values may not be correct. */
- { &ops, F71859_SP1, PNP_IO0 | PNP_IRQ0, { 0x7f8, 0 }, },
-
+ /* TODO: Some of the 0x07f8 etc. values may not be correct. */
+ { &ops, F71859_SP1, PNP_IO0 | PNP_IRQ0, {0x07f8, 0}, },
};
static void enable_dev(device_t dev)